# NOTES ON CERTIFICATE LOCATIONS
#
# For systems with /etc/pki (e.g. FC4 and later):
# Certificate:	/etc/pki/dovecot/certs/dovecot.pem
# Key:		/etc/pki/dovecot/private/dovecot.pem
# Note that this is different from old Fedora packages, which generate
# the certificate at /etc/pki/dovecot/dovecot.pem but it is compatible
# with current Fedora packages
#
# For systems without /etc/pki (e.g. FC3 and older, RHEL4 and older):
# Certificate:	/usr/share/ssl/certs/dovecot.pem
# Key:		/usr/share/ssl/private/dovecot.pem

# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Remember to bump dovecot_release, sieve_release, and manage_sieve_release with every release
%global dovecot_epoch 1
%global dovecot_version 1.2.17
%global dovecot_release 3.0.cf.%{__distinit}%{__distvers}
%global sieve_epoch 2
%global sieve_version 0.1.19
%global sieve_release 1.1.cf.%{__distinit}%{__distvers}
%global manage_sieve_dovecot_patch_version 1.2.17
%global manage_sieve_epoch 2
%global manage_sieve_version 0.11.13
%global manage_sieve_release 1.1.cf.%{__distinit}%{__distvers}

# sqlite-devel available from FC4, RHEL4 onwards
%if "%{__distinit}" == "fc" && %{__distvers} >= 4 || "%{__distinit}" == "rhel" && %{__distvers} >= 4
%global build_sqlite 1
%endif

# krb5-devel ≥ 1.3 available from FC1, RHEL4 onwards
%if "%{__distinit}" == "fc"
%global build_gssapi 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 4
%global build_gssapi 1
%endif

# Suitably recent cURL and expat needed for solr support
%if "%{__distinit}" == "fc" && %{__distvers} >= 4
%global build_solr 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 5
%global build_solr 1
%endif

# This macro only defined by default around Fedora 10 time
%{!?_initddir:%global _initddir %{_sysconfdir}/rc.d/init.d}

Summary:	Dovecot IMAP server
Name:		dovecot
Epoch:		%{dovecot_epoch}
Version:	%{dovecot_version}
Release:	%{dovecot_release}
# dovecot itself is MIT, a few sources are PD, perfect_maildir.pl is GPLv2+
License:	MIT and GPLv2+
URL:		http://www.dovecot.org/
Group:		System Environment/Daemons
Source0:	http://www.dovecot.org/releases/1.2/dovecot-%{dovecot_version}.tar.gz
Source1:	dovecot.init
Source2:	dovecot.pam
Source3:	maildir-migration.txt
Source4:	migrate-folders
Source5:	migrate-users
Source6:	perfect_maildir.pl
Source7:	dovecot-REDHAT-FAQ.txt
Source8:	http://www.rename-it.nl/dovecot/1.2/dovecot-1.2-sieve-%{sieve_version}.tar.gz
Source9:	dovecot.sysconfig
Source10:	http://www.rename-it.nl/dovecot/1.2/dovecot-1.2-managesieve-%{manage_sieve_version}.tar.gz
Source20:	dovecot.conf.5
Source21:	dovecotpw.1
Source22:	dovecot.8
Patch0:		http://www.rename-it.nl/dovecot/1.2/dovecot-%{manage_sieve_dovecot_patch_version}-managesieve-%{manage_sieve_version}.diff.gz
# Fedora patches
Patch1:		dovecot-1.2-default-settings.patch
Patch2:		dovecot-1.0.beta2-mkcert-permissions.patch
# Local patches
Patch500:	dovecot-1.1.7-SSLDIR.patch
Patch501:	dovecot-1.2-login-dir.patch
BuildRequires:	gcc-c++
BuildRequires:	openssl-devel, pam-devel, zlib-devel
BuildRequires:	openldap-devel %{?build_gssapi: krb5-devel >= 1.3}
BuildRequires:	pkgconfig
# The following buildreq is supplied by gettext-devel in current
# distributions, and by gettext in older distributions
#BuildRequires: /usr/share/aclocal/iconv.m4
# We don't actually need it because we don't run autotools in this build
#
BuildRequires:	libcap-devel mysql-devel postgresql-devel %{?build_sqlite:sqlite-devel}
%if 0%{?build_solr}
# cURL library needed for Solr full text search support
# Actual buildreq may be curl-devel or libcurl-devel, depending on distribution
# Need expat too
BuildRequires:	/usr/include/curl/curl.h, expat-devel
%endif
BuildRoot:	%{_tmppath}/%{name}-%{dovecot_version}-%{dovecot_release}-root-%(id -nu)
# Package includes an initscript service file, needs to require initscripts package
Requires:	initscripts
# /etc/rc.d/rc.sysinit needed at build time so we can tell if we need to move the login dir
BuildRequires:	initscripts

# Old packages merged into dovecot
Obsoletes:	dovecot-sqlite	< %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
Obsoletes:	dovecot-ldap	< %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
Obsoletes:	dovecot-gssapi	< %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
Provides:	dovecot-sqlite	= %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
Provides:	dovecot-ldap	= %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
Provides:	dovecot-gssapi	= %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

Requires(pre):	shadow-utils
Requires(post): openssl, /sbin/chkconfig
Requires(preun):/sbin/chkconfig

# Figure out where ssl stuff goes
%global use_pki %(if [ -f %{_sysconfdir}/pki/tls/certs/ca-bundle.crt ]; then echo 1; else echo 0; fi)
%if %{use_pki}
%global ssldir %{_sysconfdir}/pki/dovecot
%else
%global ssldir %{_datadir}/ssl
%endif

# FC4, RHEL4 and older don't handle /var/run/dovecot/login/* properly, so we
# move it to /var/run/dovecot-login instead
%global move_login_dir %(grep -E 'dovecot.*afile|find.*/var/run .*-exec rm' /etc/rc.d/rc.sysinit &> /dev/null && echo 0 || echo 1)
%if %{move_login_dir}
%global login_dir dovecot-login
%else
%global login_dir dovecot/login
%endif

%global docdir %{_docdir}/dovecot-%{dovecot_version}
%global dovecot_uid 97
%global dovecot_gid 97

%description
Dovecot is an IMAP server for Linux/UNIX-like systems, written with security 
primarily in mind. It also contains a small POP3 server. It supports mail 
in either maildir or mbox formats.

%package devel
Summary:	Headers and config script needed for building plugins
Group:		Development/Libraries
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
# The devel package needs to require the same packages as the main package buildrequires
Requires:	gcc-c++, openssl-devel, openldap-devel, pam-devel, pkgconfig, zlib-devel

%description devel
This package provides header files and configuration scripts required for
building plug-ins for the dovecot IMAP/POP3 server.

%package pigeonhole
Summary:	Sieve and Managesieve plug-in for dovecot
Group:		System Environment/Daemons
URL:		http://pigeonhole.dovecot.org/
License:	LGPLv2+
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

# Old packages merged into pigeonhole
Obsoletes:	dovecot-sieve < %{sieve_epoch}:%{sieve_version}-%{sieve_release}
Obsoletes:	dovecot-managesieve < %{manage_sieve_epoch}:%{manage_sieve_version}-%{manage_sieve_release}
Provides:	dovecot-sieve = %{sieve_epoch}:%{sieve_version}-%{sieve_release}
Provides:	dovecot-managesieve = %{manage_sieve_epoch}:%{manage_sieve_version}-%{manage_sieve_release}

%description pigeonhole
This package provides the sieve %{sieve_version} and managesieve %{manage_sieve_version} plug-ins
for dovecot LDA.

%package pgsql
Summary:	Postgres SQL back end for dovecot
Group:		System Environment/Daemons
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

%description pgsql
This package provides the Postgres SQL back end for dovecot-auth etc.

%package mysql
Summary:	MySQL back end for dovecot
Group:		System Environment/Daemons
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

%description mysql
This package provides the MySQL back end for dovecot-auth etc.

%prep
%setup -q -n dovecot-%{dovecot_version}
%patch0 -p1 -b .managesieve
%setup -q -n dovecot-%{dovecot_version} -D -T -a 8 -a 10
%patch1 -p1 -b .default-settings
%patch2 -p1 -b .mkcert-permissions

%patch500 -p1
%if %{move_login_dir}
%patch501 -p0
%endif

# PAM Configuration:
# Default PAM configuration file uses password-auth common config;
# revert to system-auth if password-auth is not available
cp -p %{SOURCE2} .
if [ ! -f /etc/pam.d/password-auth ]; then
	sed -i -e s/password-auth/system-auth/ dovecot.pam
fi
# The "include" syntax used in our PAM configuration file was introduced in
# PAM 0.78 and is therefore supported in FC-5 and EL-5 onwards; older
# distributions such as EL-4 (PAM 0.77) need to fall back to using the
# now-deprecated pam_stack module. Since the pam-devel package doesn't
# include a pkgconfig file from which we could check the version number, we
# instead check for the absence of the file /etc/pam.d/config-util, which is
# present in all PAM packages from 0.80 onwards and acts as a useful
# indicator of the need to fall back to pam_stack.
[ ! -f /etc/pam.d/config-util ] && sed -i -e \
	's/include[[:space:]]*system-auth/required'\ \ \ \ \ 'pam_stack.so service=system-auth/' \
	dovecot.pam

# Fix certificate locations
sed -i -e 's#@SSLDIR@#%{ssldir}#g' dovecot-example.conf doc/mkcert.sh

# Fix character encodings
/usr/bin/iconv -f iso-8859-1 -t utf8 < doc/auth-protocol.txt > auth-protocol.txt
mv -f auth-protocol.txt doc/auth-protocol.txt

# Copy in manpages
cp -p %{SOURCE20} %{SOURCE21} %{SOURCE22} .

%build
# Don't try to use Linux 2.6 epoll for targets that use Linux 2.4 kernels
%if "%{__distinit}" == "rhl" || "%{__distinit}%{__distvers}" == "fc1" || "%{__distinit}%{__distvers}" == "rhel3"
export i_cv_epoll_works=no
%endif
%configure \
			--disable-dependency-tracking	\
			--enable-header-install		\
			--with-libcap			\
			--with-pam			\
			--with-pgsql			\
			--with-mysql			\
%{?build_solr:		--with-solr}			\
%{?build_sqlite:	--with-sqlite}			\
			--with-sql=plugin		\
			--with-sql-drivers		\
			--with-ldap=plugin		\
			--with-ssl=openssl		\
			--with-ssldir=%{ssldir}		\
%{?build_gssapi:	--with-gssapi=plugin}		\
			--without-bzlib
make %{?_smp_mflags}

# Configure and build sieve
cd dovecot-1.2-sieve-%{sieve_version}
%configure --disable-static --with-dovecot=../ --with-unfinished-features
make %{?_smp_mflags}
cd -

# Configure and build managesieve
cd dovecot-1.2-managesieve-%{manage_sieve_version}
%configure							\
	INSTALL_DATA="install -c -p -m644"			\
	--disable-static					\
	--with-dovecot=../					\
	--with-dovecot-sieve=../dovecot-1.2-sieve-%{sieve_version}/
make %{?_smp_mflags}
cd -

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALL_DATA="install -c -p -m644" docdir=%{docdir}
mkdir -p %{buildroot}{%{_sysconfdir}/pam.d,%{_initddir}}
install -p -m 755 %{SOURCE1} %{buildroot}%{_initddir}/dovecot
install -p -m 644 dovecot.pam %{buildroot}%{_sysconfdir}/pam.d/dovecot
mkdir -p %{buildroot}%{_libexecdir}/dovecot
install -p -m 755 src/plugins/convert/convert-tool %{buildroot}%{_libexecdir}/dovecot
mkdir -p %{buildroot}%{_localstatedir}/run/dovecot
mkdir -p %{buildroot}%{_localstatedir}/run/%{login_dir}
chmod 755 %{buildroot}%{_localstatedir}/run/dovecot
chmod 750 %{buildroot}%{_localstatedir}/run/%{login_dir}
mkdir -p %{buildroot}%{_localstatedir}/lib/dovecot
chmod 750 %{buildroot}%{_localstatedir}/lib/dovecot
mkdir -p %{buildroot}%{ssldir}
install -p -m 644 doc/dovecot-openssl.cnf %{buildroot}%{ssldir}/dovecot-openssl.cnf

# Install the certificate generating script in %%{_libexecdir}/dovecot
install -p -m 755 doc/mkcert.sh %{buildroot}%{_libexecdir}/dovecot/mkcert.sh

# Install the daemon configuration file
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 600 %{SOURCE9} %{buildroot}%{_sysconfdir}/sysconfig/dovecot

# Generate ghost .pem files
mkdir -p %{buildroot}%{ssldir}/{certs,private}
: > %{buildroot}%{ssldir}/certs/dovecot.pem
: > %{buildroot}%{ssldir}/private/dovecot.pem

# Install some of our own documentation
install -p -m 644 %{SOURCE7} %{buildroot}%{docdir}/REDHAT-FAQ.txt
mkdir -p %{buildroot}%{docdir}/UW-to-Dovecot-Migration
install -p -m 644 %{SOURCE3} %{SOURCE4} %{SOURCE5} %{SOURCE6} \
	%{buildroot}%{docdir}/UW-to-Dovecot-Migration/

# Install some example configurations, but not in %%{_sysconfdir}
mkdir -p %{buildroot}%{docdir}/examples
rm %{buildroot}%{_sysconfdir}/dovecot-{db,dict-sql,ldap,sql}-example.conf
install -p -m 644 doc/dovecot-{db,dict-sql,ldap,sql}-example.conf \
	dovecot-example.conf \
	%{buildroot}%{docdir}/examples/
install -p -m 644 dovecot-example.conf \
	%{buildroot}%{docdir}/dovecot.conf.default

# Install some additional documentation
install -p -m 644 AUTHORS COPYING* ChangeLog INSTALL NEWS README TODO \
	%{buildroot}%{docdir}

# Have the configuration file use the right name
mv %{buildroot}%{_sysconfdir}/dovecot-example.conf %{buildroot}%{_sysconfdir}/dovecot.conf

# Install sieve plug-in
cd dovecot-1.2-sieve-%{sieve_version}
make install \
	DESTDIR=%{buildroot} \
	INSTALL_DATA="install -c -p -m644" \
	sieve_docdir=%{_docdir}/dovecot-sieve-%{sieve_version}
cd -

# Some sieve documentation
mkdir -p %{buildroot}%{_docdir}/dovecot-sieve-%{sieve_version}/
cp -p dovecot-1.2-sieve-%{sieve_version}/{AUTHORS,COPYING*,NEWS} \
	%{buildroot}%{_docdir}/dovecot-sieve-%{sieve_version}/

# Install dovecot-managesieve
cd dovecot-1.2-managesieve-%{manage_sieve_version}
make install DESTDIR=%{buildroot}
cd -

# Install additional manpages
mkdir -p %{buildroot}%{_mandir}/man{1,5,8}
install -p -m 644 dovecotpw.1 %{buildroot}%{_mandir}/man1
install -p -m 644 dovecot.conf.5 %{buildroot}%{_mandir}/man5
install -p -m 644 dovecot.8 %{buildroot}%{_mandir}/man8

# Blow away static libraries
find %{buildroot}/%{_libdir}/dovecot -name '*.a' -exec rm -f {} \;

# Blow away libtool archives
find %{buildroot}/%{_libdir}/dovecot -name '*.la' -exec rm -f {} \;

%check
make -C dovecot-1.2-sieve-%{sieve_version} test

%clean
rm -rf %{buildroot}

%pre
# Create account for dovecot to run as
/usr/bin/getent group dovecot > /dev/null || \
	/usr/sbin/groupadd -g %{dovecot_gid} -r dovecot
/usr/bin/getent passwd dovecot > /dev/null || \
	/usr/sbin/useradd -r -u %{dovecot_uid} -g dovecot \
		-d %{_libexecdir}/dovecot -M -s /sbin/nologin \
		-c "Dovecot IMAP Server" dovecot
exit 0

%post
/sbin/chkconfig --add dovecot || :

%if %{use_pki}
# Migrate SSL certificates from old locations if present
# Use cp rather than mv to avoid breakage of existing configuration
[ -f %{ssldir}/dovecot.pem -a ! -e %{ssldir}/certs/dovecot.pem ] &&
	cp -p %{ssldir}/dovecot.pem %{ssldir}/certs/dovecot.pem
[ -f %{_datadir}/ssl/certs/dovecot.pem -a ! -e %{ssldir}/certs/dovecot.pem ] &&
	cp -p %{_datadir}/ssl/certs/dovecot.pem %{ssldir}/certs/dovecot.pem || :
[ -f %{_datadir}/ssl/private/dovecot.pem -a ! -e %{ssldir}/private/dovecot.pem ] &&
	cp -p %{_datadir}/ssl/private/dovecot.pem %{ssldir}/private/dovecot.pem || :
%endif

# Create SSL keys/certs
[ ! -f %{ssldir}/certs/dovecot.pem ] && %{docdir}/examples/mkcert.sh &> /dev/null || :

# Generate DH SSL parameters
if [ ! -f %{_localstatedir}/lib/dovecot/ssl-parameters.dat ]; then
	%{_libexecdir}/dovecot/ssl-build-param \
		%{_localstatedir}/lib/dovecot/ssl-parameters.dat &> /dev/null || :
fi
exit 0

%preun
if [ $1 = 0 ]; then
	%{_initddir}/dovecot stop &> /dev/null || :
	/sbin/chkconfig --del dovecot
fi

%postun
# service restarted in %%postun rather than %%post for the benefit of people doing composes in chroots
if [ "$1" -ge "1" ]; then
	%{_initddir}/dovecot condrestart &> /dev/null || :
fi

%files
%defattr(-,root,root,-)
%dir %{docdir}/
%dir %{docdir}/examples/
%doc %{docdir}/[A-Z]*
%doc %{docdir}/[a-z]*.txt
%doc %{docdir}/dovecot.conf.default
%doc %{docdir}/examples/*.conf
%doc %{docdir}/wiki/
%config(noreplace) %{_sysconfdir}/dovecot.conf
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/dovecot
%{_initddir}/dovecot
%config(noreplace) %{_sysconfdir}/pam.d/dovecot
%config(noreplace) %{ssldir}/dovecot-openssl.cnf
%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{ssldir}/certs/dovecot.pem
%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{ssldir}/private/dovecot.pem
%dir %{_libexecdir}/dovecot/
%{_sbindir}/dovecot
%{_sbindir}/dovecotpw
%{_libexecdir}/dovecot/authtest
%{_libexecdir}/dovecot/checkpassword-reply
%{_libexecdir}/dovecot/convert-tool
%{_libexecdir}/dovecot/deliver
%{_libexecdir}/dovecot/dict
%{_libexecdir}/dovecot/dovecot-auth
%{_libexecdir}/dovecot/expire-tool
%{_libexecdir}/dovecot/gdbhelper
%{_libexecdir}/dovecot/idxview
%{_libexecdir}/dovecot/imap
%{_libexecdir}/dovecot/imap-login
%{_libexecdir}/dovecot/imap-utf7
%{_libexecdir}/dovecot/listview
%{_libexecdir}/dovecot/logview
%{_libexecdir}/dovecot/maildirlock
%{_libexecdir}/dovecot/mkcert.sh
%{_libexecdir}/dovecot/pop3
%{_libexecdir}/dovecot/pop3-login
%{_libexecdir}/dovecot/rawlog
%{_libexecdir}/dovecot/ssl-build-param
%{_libexecdir}/dovecot/threadview
%dir %{_libdir}/dovecot/
%dir %{_libdir}/dovecot/auth/
%dir %{_libdir}/dovecot/dict/
%dir %{_libdir}/dovecot/lda/
%dir %{_libdir}/dovecot/sql/
%{_libdir}/dovecot/auth/libauthdb_ldap.so
%if 0%{?build_gssapi}
%{_libdir}/dovecot/auth/libmech_gssapi.so
%endif
%if 0%{?build_sqlite}
%{_libdir}/dovecot/auth/libdriver_sqlite.so
%{_libdir}/dovecot/dict/libdriver_sqlite.so
%{_libdir}/dovecot/sql/libdriver_sqlite.so
%endif
%{_libdir}/dovecot/imap/
%{_libdir}/dovecot/lib01_acl_plugin.so
%{_libdir}/dovecot/lib02_lazy_expunge_plugin.so
%{_libdir}/dovecot/lib10_quota_plugin.so
%{_libdir}/dovecot/lib11_trash_plugin.so
%{_libdir}/dovecot/lib20_autocreate_plugin.so
%{_libdir}/dovecot/lib20_convert_plugin.so
%{_libdir}/dovecot/lib20_expire_plugin.so
%{_libdir}/dovecot/lib20_fts_plugin.so
%{_libdir}/dovecot/lib20_listescape_plugin.so
%{_libdir}/dovecot/lib20_mail_log_plugin.so
%{_libdir}/dovecot/lib20_mbox_snarf_plugin.so
%{_libdir}/dovecot/lib20_zlib_plugin.so
%{_libdir}/dovecot/lib20_virtual_plugin.so
%if 0%{?build_solr}
%{_libdir}/dovecot/lib21_fts_solr_plugin.so
%endif
%{_libdir}/dovecot/lib21_fts_squat_plugin.so
%{_libdir}/dovecot/lda/lib01_acl_plugin.so
%{_libdir}/dovecot/lda/lib10_quota_plugin.so
%{_libdir}/dovecot/lda/lib11_trash_plugin.so
%{_libdir}/dovecot/lda/lib20_autocreate_plugin.so
%{_libdir}/dovecot/lda/lib20_convert_plugin.so
%{_libdir}/dovecot/lda/lib20_expire_plugin.so
%{_libdir}/dovecot/lda/lib20_fts_plugin.so
%{_libdir}/dovecot/lda/lib20_listescape_plugin.so
%{_libdir}/dovecot/lda/lib20_mail_log_plugin.so
%{_libdir}/dovecot/lda/lib20_virtual_plugin.so
%if 0%{?build_solr}
%{_libdir}/dovecot/lda/lib21_fts_solr_plugin.so
%endif
%{_libdir}/dovecot/lda/lib21_fts_squat_plugin.so
%{_libdir}/dovecot/pop3/
%dir %{_localstatedir}/run/dovecot/
%attr(0750,root,dovecot) %dir %{_localstatedir}/lib/dovecot/
%attr(0750,root,dovecot) %dir %{_localstatedir}/run/%{login_dir}/
%{_mandir}/man1/dovecotpw.1*
%{_mandir}/man5/dovecot.conf.5*
%{_mandir}/man8/dovecot.8*

%files devel
%defattr(-,root,root,-)
%{_includedir}/dovecot/
%{_libdir}/dovecot/dovecot-config

%files pigeonhole
%defattr(-,root,root,-)
%doc %{_docdir}/dovecot-sieve-%{sieve_version}/
%{_bindir}/sieve-filter
%{_bindir}/sievec
%{_bindir}/sieved
%{_bindir}/sieve-test
%{_libdir}/dovecot/lda/lib90_sieve_plugin.so
%{_libexecdir}/dovecot/managesieve
%{_libexecdir}/dovecot/managesieve-login
%{_mandir}/man1/sievec.1*
%{_mandir}/man1/sieved.1*
%{_mandir}/man1/sieve-filter.1*
%{_mandir}/man1/sieve-test.1*

%files mysql
%defattr(-,root,root,-)
%{_libdir}/dovecot/auth/libdriver_mysql.so
%{_libdir}/dovecot/dict/libdriver_mysql.so
%{_libdir}/dovecot/sql/libdriver_mysql.so

%files pgsql
%defattr(-,root,root,-)
%{_libdir}/dovecot/auth/libdriver_pgsql.so
%{_libdir}/dovecot/dict/libdriver_pgsql.so
%{_libdir}/dovecot/sql/libdriver_pgsql.so

%changelog
* Fri Oct 14 2011 Paul Howarth <paul@city-fan.org> 1:1.2.17-3.0.cf
- fix dist tag for CentOS 6 and Scientific Linux

* Fri May 20 2011 Paul Howarth <paul@city-fan.org> 1:1.2.17-2.0.cf
- update dovecot-sieve to 0.1.19
  - enotify extension: fixed inappropriate return type in mailto URI parse
    function, also fixing ARM compiler warning
  - vacation extension: fixed handling of sendmail errors; it produced an
    additional confusing success message in case of error
  - removed header MIME-decoding to fix erroneous address parsing (applies to
    address test and vacation command)
- update dovecot-managesieve to 0.11.13
  - ManageSieve: fixed bug in UTF-8 checking of string values
- update managesieve patch to 1.2.17 (no changes)

* Thu May 12 2011 Paul Howarth <paul@city-fan.org> 1:1.2.17-1.0.cf
- update dovecot to 1.2.17
  - fixed potential crashes and other problems when parsing header names that
    contained NUL characters
  - IMAP: fixed a memory leak with ESEARCH command handling
  - quota warnings could have been executed at incorrect times with some
    configs
- nobody else likes macros for commands

* Wed Nov 10 2010 Paul Howarth <paul@city-fan.org> 1:1.2.16-1.0.cf
- update dovecot to 1.2.16
  - imap: fixed SELECT QRESYNC not to crash on mailbox close
  - pop3: fixed a potential hang
  - mbox: new mailboxes base permissions on mail root dir, not always use 0600
  - auth: disable auth caching entirely for master users

* Mon Oct 25 2010 Paul Howarth <paul@city-fan.org> 1:1.2.15-2.0.cf
- do not use dotlocking by default for deliver too (#629020)

* Tue Oct  5 2010 Paul Howarth <paul@city-fan.org> 1:1.2.15-1.0.cf
- update dovecot to 1.2.15
  - acl: fixed the logic of merging multiple ACL entries
  - acl: don't give admin rights to all owner mailboxes
  - Maildir: fixed potential "Duplicate file entry" error in dovecot-uidlist
  - Maildir: avoid unnecessary uidlist recreation during mail delivery
  - imap: when SELECT fails, it didn't close the previous mailbox
  - Dovecot master process could have died if it got a burst of SIGCHLD signals
- update sieve to 0.1.18
  - Imap4flags: fixed segfault bug occuring in multiscript context
  - Imap4flags: fixed bug in setflag command with stringlist parameter
  - prevented assertion failure due to corrupt binary string representation
  - Multiscript: fixed duplicate implicit keep
  - fixed Sieve script name checking to properly handle length limit
  - removed spurious old stdio.h (top) includes
  - fixed default Sieve capability (as reported by ManageSieve)
  - fixed unnecessary reporting of dummy extensions in Sieve capability
  - Variables extension: fixed :length set modifier to recognize utf8 characters
  - LDA Sieve plugin: added _version symbol
- update managesieve to 0.11.12
  - fixed error handling of PUTSCRIPT commmand
  - fixed PUTSCRIPT bug causing it to hang when given an empty script name

* Wed Aug 25 2010 Paul Howarth <paul@city-fan.org> 1:1.2.14-1.0.cf
- update dovecot to 1.2.14
  - virtual mailboxes: added support for IDLE notifications
  - master: don't crash on config reload when using dict processes
  - imap: QRESYNC parameters for SELECT weren't handled correctly
- drop upstreamed QRESYNC patch

* Fri Aug 20 2010 Paul Howarth <paul@city-fan.org> 1:1.2.13-2.0.cf
- imap: don't crash with QRESYNC SELECT specifying sequences larger
  than mailbox's message count (#625207)

* Tue Jul 27 2010 Paul Howarth <paul@city-fan.org> 1:1.2.13-1.1.cf
- update managesieve patch to 1.2.13 version (no changes)
- run sieve test suite in %%check

* Mon Jul 26 2010 Paul Howarth <paul@city-fan.org> 1:1.2.13-1.0.cf
- update dovecot to 1.2.13
  - acl: don't use INBOX's ACLs as default ACLs if their paths are the same
  - fixed iconv() crash processing several kilobytes of broken continuous input
  - don't log cache corruption errors if MIME encoded-words contain line feeds
  - mbox: renaming mailbox under newly created dir didn't move index directory
  - mbox: fix generation of envelope to From_-line

* Mon Jun 19 2010 Paul Howarth <paul@city-fan.org> 1:1.2.12-1.1.cf
- don't try to use Linux 2.6 epoll for targets that use Linux 2.4 kernels

* Sat Jun 19 2010 Paul Howarth <paul@city-fan.org> 1:1.2.12-1.0.cf
- update dovecot to 1.2.12
  - deliver: fix crash when message with Auto-submitted: header gets rejected
  - lib-storage: fixed header searches with multiple headers with same name
  - dict client: disconnect from dict server after 1 second of idling
  - dict: if process crashed, it wasn't automatically restarted
  - dict file: don't change dict file's GID unnecessarily
  - maildir: fixed a memory leak when copying with hardlinks
  - maildir: fix crash when expunging last messages with changed filenames
- update sieve to 0.1.17
  - ensure source code positions for compiler messages recorded at token starts
  - fixed a few potential memory leaks
  - made command line tools return proper exit status upon failure

* Tue Jun  1 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-4.0.cf
- build with Solr full text search support where possible (#595933)
- buildreq libcurl-devel and expat-devel for Solr support

* Tue May 25 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-3.2.cf
- fix dist tag for RHEL-6 Beta

* Fri Apr 30 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-3.1.cf
- updated dovecot-sieve to 0.1.16
  - extensions spamtest, spamtestplus and virustest implemented
  - vacation extension: from address set based on recipient alias
  - restructured and optimized the lexical scanner
  - added --with-docs configure option
  - fixed compile failures on certain systems
  - imapflags extension now deprecated
  - fixed various memset argument mixups in enotify extension

* Tue Mar 23 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-3.0.cf
- drop mbox bzip support as it's broken and upstream does not plan to fix it in
  dovecot 1.2 (http://www.dovecot.org/list/dovecot/2010-February/046789.html)
- use managesieve patch for dovecot 1.2.11

* Fri Mar 11 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-2.0.cf
- rebuild: Fedora version didn't have bzip2 support (#572797)

* Tue Mar  9 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-1.0.cf
- updated dovecot to 1.2.11
  - mbox: message header reading was unnecessarily slow and CPU-intensive
  - mbox, dbox, cydir: fix mail root directory permissions
  - maildir: reading uidlist could have ended up in an infinite loop
  - IMAP IDLE: v1.2.7+ caused extra load by checking changes too often

* Wed Feb 24 2010 Paul Howarth <paul@city-fan.org> 1:1.2.10-4.0.cf
- merged dovecot-sieve and dovecot-managesieve into dovecot-pigeonhole
- merged dovecot-sqlite, dovecot-gssapi and dovecot-ldap into dovecot

* Thu Jan 28 2010 Paul Howarth <paul@city-fan.org> 1:1.2.10-2.0.cf
- rebuild

* Mon Jan 25 2010 Paul Howarth <paul@city-fan.org> 1:1.2.10-1.0.cf
- dovecot updated to 1.2.10
  - %%variables now support %%{host}, %%{pid} and %%{env:VAR_NAME} everywhere
  - LIST-STATUS capability is now advertised
  - maildir: Fixed several assert-crashes.
  - imap: LIST "" inbox shouldn't crash if using namespace with "INBOX." prefix
  - lazy_expunge now ignores non-private namespaces
- sieve updated to 0.1.15
  - enotify: adjusted notify method API for addition of new methods
  - enotify: set default importance level to 'normal' (was 'high')
  - include: updated implementation towards most recent specification
  - envelope path parser allows addresses that have no domain part
  - preliminary support for Sieve plugins
  - support for installing Sieve development headers
  - deprecated notify extension: implemented denotify command
  - variables extension: added support for variable namespaces
  - added configurable script size limit
  - testsuite enhancements
  - fixed a bug in the i;ascii-numeric comparator (see NEWS)
  - imap4flags: fixed bug in removeflag (see NEWS)
  - improved some error messages
  - fixed typo in runtime log message for vacation extension
  - fixed parser recovery
- managesieve updated to 0.11.11
  - adjustments to match changes in the Sieve API
  - implement ManageSieve QUOTA enforcement
  - added MAXREDIRECTS capability after login
  - implement ew script name rules specified in most recent ManageSieve draft
  - fix assertion failure occuring with challenge-response SASL mechanisms

* Tue Dec 22 2009 Paul Howarth <paul@city-fan.org> 1:1.2.9-2.0.cf
- dovecot updated to 1.2.9
  - maildir: when saving, filenames now always contain ,S=<size>
  - maildir: fix assert-crashes in v1.2.7 and v1.2.8
  - maildir_copy_preserve_filename=yes could have caused crashes
  - maildir++ quota: update %% limits from maildirsize
  - virtual: v1.2.8 didn't fully fix the "lots of mailboxes" bug
  - virtual: fixed updating virtual mailbox based on flag changes
  - fts-squat: fixed searching multi-byte characters
- sieve updated to 0.1.14
  - limits of redirects and actions now configurable
  - extension handling no longer needs to maintain global state
  - made LDA Sieve plugin recognize the deliver_log_format setting
  - outgoing message headers now RFC2047-encoded
  - add support for the $text$ substitution in the deprecated notify extension
  - recipient_delimiter is now an alias for sieve_subaddress_sep
  - fixed logging of mailbox names (uses UTF8)
  - fix a minor memory leak in the multiscript support
  - fix a bug in the recompilation of Sieve scripts (only done when needed)
- managesieve updated to 0.11.10
  - adjustments to match changes in the Pigeonhole Sieve API (requires 0.1.14)
  - fix compilation of ManageSieve against CMUSieve

* Wed Nov 25 2009 Paul Howarth <paul@city-fan.org> 1:1.2.8-4.0.cf
- fix dovecot's restart after update (#518753)

* Tue Nov 24 2009 Paul Howarth <paul@city-fan.org> 1:1.2.8-2.0.cf
- use managesieve patch for dovecot 1.2.8

* Fri Nov 20 2009 Paul Howarth <paul@city-fan.org> 1:1.2.8-1.0.cf
- dovecot updated to 1.2.8
  - fix base_dir's permissions from 0777 to 0755 (see NEWS)
  - merge acls from multiple groups
  - virtual: fix OOM when using a lot of mailboxes
  - return RFC 2231 "key*" fields correctly in FETCH BODYSTRUCTURE

* Mon Nov 16 2009 Paul Howarth <paul@city-fan.org> 1:1.2.7-3.0.cf
- use upstream managesieve patch for dovecot 1.2.7
- rawhide dist tag no longer needs special-casing

* Fri Nov 13 2009 Paul Howarth <paul@city-fan.org> 1:1.2.7-2.0.cf
- add default config copy in %%{docdir}
- add manpages for dovecot(8), dovecot.conf(5), dovecotpw(1)

* Tue Nov  9 2009 Paul Howarth <paul@city-fan.org> 1:1.2.7-1.0.cf
- dovecot updated to 1.2.7
  - imap: send "still here" notifications for user's connections simultaneously
  - imap: if imap_capability is set, show it in the login banner
  - imap: implemented SORT=DISPLAY extension
  - login: fix process creation epoll_ctl() errors
  - maildir: fix some performance issues
  - maildir: fix crash when using a lot of keywords
  - several fixes to QRESYNC extension and modseq handling
  - mbox: make sure failed saves get rolled back with NFS
  - dbox: several fixes
- update managesieve patch locally to apply against dovecot 1.2.7
- drop upstreamed imap_capability patch
- drop SSL compression patch; issue resolved upstream

* Mon Nov  2 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-5.0.cf
- minor spec clean-up

* Thu Oct 22 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-4.0.cf
- imap-login: if imap_capability is set, show it in the banner instead of the
  default (#524485)

* Thu Oct 22 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-3.0.cf
- fix initscript for case when no action was specified

* Mon Oct 19 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-1.1.cf
- sieve updated to 0.1.13
  - body extension: proper handling of the :raw transform
  - body extension: added various new tests to the test suite
  - body extension: don't give SKIP_BODY_BLOCK flag to message parser
  - fix race condition when multiple instances are saving the same binary
  - multiscript: subsequent keep actions merged correctly
  - multiscript: implicit side effects handled correctly
  - sieve-test: fix segfault when compile fails
  - fix segfault in action processing when merging side effects
  - fix sieve plugin to not stat() a NULL path, yielding a 'Bad address' error

* Tue Oct  6 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-1.0.cf
- dovecot updated to 1.2.6
  - added authtest utility for doing passdb and userdb lookups
  - login: ssl_security string now also shows the used compression
  - quota: Don't crash with non-Maildir++ quota backend
  - imap proxy: Fixed crashing with some specific password characters
  - dovecot --exec-mail was broken
  - avoid assert-crashing when two processes try to create index simultaneously
- update managesieve patch to 1.2.6 version
- add patch to revert ssl_proxy_get_security_string() to the dovecot-1.2.5
  version if we have openssl < 0.9.8, which does not have the required
  functions SSL_COMP_get_name and SSL_get_current_compression

* Wed Sep 30 2009 Paul Howarth <paul@city-fan.org> 1:1.2.5-2.0.cf
- use password-auth common PAM configuration instead of system-auth
- use %%{_initddir} rather than %%{_initrddir}
- add some UID=0 checks in the initscript

* Mon Sep 14 2009 Paul Howarth <paul@city-fan.org> 1:1.2.5-1.0.cf
- dovecot updated to 1.2.5
- authentication: DIGEST-MD5 and RPA mechanisms no longer require
  user's login realm to be listed in auth_realms; it only made
  configuration more difficult without really providing extra security
- zlib plugin: don't allow clients to save compressed data directly;
  this prevents users from exploiting (most of the) potential security
  holes in zlib/bzlib
- fix index file handling that could have caused an assert-crash
- IMAP: fixes to QRESYNC extension
- deliver: don't send rejects to any messages that have Auto-Submitted
  header; this avoids emails loops

* Mon Aug 31 2009 Paul Howarth <paul@city-fan.org> 1:1.2.4-2.0.cf
- rebuild for openssl 1.0 in Rawhide

* Fri Aug 21 2009 Paul Howarth <paul@city-fan.org> 1:1.2.4-1.1.cf
- sieve updated to 0.1.12
- managesieve updated to 0.11.9
- drop dovecot-1.2.4-managesieve-0.11.8 patch, no longer needed

* Tue Aug 18 2009 Paul Howarth <paul@city-fan.org> 1:1.2.4-1.0.cf
- dovecot updated to 1.2.4
- sieve updated to 0.1.11
- add http://pigeonhole.dovecot.org/ URL for sieve and managesieve packages
- add manpage for sieve-filter
- add patch to fix managesieve build against dovecot-1.2.4

* Mon Aug 10 2009 Paul Howarth <paul@city-fan.org> 1:1.2.3-1.0.cf
- dovecot updated to 1.2.3
- managesieve updated to 0.11.8
- drop GSSAPI patch, in upstream release

* Thu Jul 30 2009 Paul Howarth <paul@city-fan.org> 1:1.2.2-2.0.cf
- apply fix from 20090728 post-release snapshot to fix GSSAPI (#506782)
- merge default-settings patch from Fedora
- add --with-unfinished-features to sieve %%configure to build sieve-filter

* Tue Jul 28 2009 Paul Howarth <paul@city-fan.org> 1:1.2.2-1.0.cf
- dovecot updated to 1.2.2
- managesieve updated to 0.11.7
- drop managesieve SASL patch, no longer needed
- sieve plugin changed from CMU to Dovecot Sieve (0.1.9, epoch bumped to 2)
- license for sieve subpackage now just LGPL v2.1 or later

* Fri Jul 10 2009 Paul Howarth <paul@city-fan.org> 1:1.2.1-1.0.cf
- dovecot updated to 1.2.1
- managesieve updated to 0.11.6
- remove managesieve timeout patch, now upstream
- add patch to managesieve for SASL changes in 1.2.1

* Thu Jul  2 2009 Paul Howarth <paul@city-fan.org> 1:1.2.0-1.0.cf
- dovecot updated to 1.2.0

* Wed Jul  1 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.6.0.rc8.cf
- dovecot updated to 1.2.rc8
- remove upstreamed ldap-plugin patch
- remove autotools patch - we're not changing any autotools input files

* Mon Jun 29 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.5.0.rc7.cf
- dovecot updated to 1.2.rc7
- autotools patch rebuilt
- add buildreq libcap-devel for capabilities-dropping support
- add patch to fix configure script for LDAP auth plugin

* Thu Jun 25 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.4.0.rc6.cf
- dovecot updated to 1.2.rc6
- add patch for timeout sanity check in managesieve that needed inverting
- imap_utf7 renamed to imap-utf7

* Wed Jun 24 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.3.0.rc5.cf
- dovecot updated to 1.2.rc5
- managesieve updated to 0.11.5
- dovecot-1.2-ldap.patch dropped
- dovecot-1.2-default-settings.patch updated from Fedora's
  dovecot-1.1-default-settings.patch
- autotools patch rebuilt
- re-enable parallel make

* Thu Apr  2 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.2.0.beta4.cf
- dovecot updated to 1.2.beta4
- managesieve updated to 0.11.3
- dovecot-1.2-ldap.patch added from Fedora
- dovecot-1.1-default-settings.patch updated from Fedora and properly named as
  dovecot-1.2-default-settings.patch
- autotools patch rebuilt
- update login-dir patch
- Fedora 9 onwards clear out /var/run in a different way to older releases;
  bear this in mind when deciding whether to move the login-dir
- make PAM configuration %%config(noreplace)
- disable parallel make (build failure on rhel3.64)

* Fri Mar 20 2009 Paul Howarth <paul@city-fan.org> 1:1.1.13-1.0.cf
- dovecot updated to 1.1.13
- update autotools patch

* Sat Mar 14 2009 Paul Howarth <paul@city-fan.org> 1:1.1.12-1.0.cf
- dovecot updated to 1.1.12
- update autotools patch

* Mon Mar  2 2009 Paul Howarth <paul@city-fan.org> 1:1.1.11-2.0.cf
- rebuild for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb  4 2009 Paul Howarth <paul@city-fan.org> 1:1.1.11-1.0.CF
- dovecot updated to 1.1.11
- update managesieve to 0.10.5
- update autotools patch

* Tue Jan 27 2009 Paul Howarth <paul@city-fan.org> 1:1.1.10-1.0.CF
- dovecot updated to 1.1.10
- locally update managesieve patch
- update autotools patch

* Mon Jan 26 2009 Paul Howarth <paul@city-fan.org> 1:1.1.9-1.0.CF
- dovecot updated to 1.1.9
- locally update managesieve patch
- update autotools patch
- inotify and docs support enabled by default, drop configure options

* Fri Jan 23 2009 Paul Howarth <paul@city-fan.org> 1:1.1.8-3.0.CF
- rebuild for new MySQL in Rawhide

* Thu Jan 15 2009 Paul Howarth <paul@city-fan.org> 1:1.1.8-2.0.CF
- dovecot updated to 1.1.8
- added managesieve support (thanks Helmut K. C. Tessarek)
- add individual epochs for dovecot, sieve, and manage_sieve since Fedora
  uses the same EVR for all three and I stick to upstream version numbers
- update autotools patch

* Mon Dec 22 2008 Paul Howarth <paul@city-fan.org> 1:1.1.7-2.1.CF
- update dovecot-sieve to 1.1.6

* Wed Dec  3 2008 Paul Howarth <paul@city-fan.org> 1:1.1.7-2.0.CF
- revert changes from 1:1.1.6-2.0.CF; password can be stored in different file
  readable only for root via !include_try directive if required

* Mon Nov 24 2008 Paul Howarth <paul@city-fan.org> 1:1.1.7-1.0.CF
- update to 1.1.7
- remove dovecot-1.1-default-settings-passwd.patch, no longer needed
- tweak default-settings and SSLDIR patches to apply without fuzz

* Wed Nov  5 2008 Paul Howarth <paul@city-fan.org> 1:1.1.6-2.0.CF
- changed comment in sysconfig to match actual state
- change permissions of deliver (now sgid) and dovecot.conf to prevent
  possible password exposure

* Thu Oct 30 2008 Paul Howarth <paul@city-fan.org> 1:1.1.6-1.0.CF
- update to 1.1.6

* Thu Oct 23 2008 Paul Howarth <paul@city-fan.org> 1:1.1.5-1.0.CF
- update to 1.1.5

* Mon Oct  6 2008 Paul Howarth <paul@city-fan.org> 1:1.1.4-1.0.CF
- update to 1.1.4

* Tue Sep  2 2008 Paul Howarth <paul@city-fan.org> 1:1.1.3-1.0.CF
- update to 1.1.3
- update autotools patch

* Wed Jul 30 2008 Paul Howarth <paul@city-fan.org> 1:1.1.2-2.0.CF
- add option from Rawhide to prompt for SSL key password at startup

* Mon Jul 28 2008 Paul Howarth <paul@city-fan.org> 1:1.1.2-1.0.CF
- update to 1.1.2
- update autotools patch
- de-fuzz SSLDIR and login-dir patches
- explicitly specify version and release for all subpackages, in the hope of
  getting rpmbuild to use the correct buildroot directory name
- new sample config: dovecot-db-example.conf
- new plugin: zlib_plugin.so
- new utility: maildirlock
- new buildreq bzip2-devel

* Fri Jun 27 2008 Paul Howarth <paul@city-fan.org> 1:1.1.1-2.0.CF
- update default settings to listen on both IPv4 and IPv6 instead of IPv6 only
- tweak dist tag macros to work on current Rawhide with three-part releasenum

* Sun Jun 22 2008 Paul Howarth <paul@city-fan.org> 1:1.1.1-1.0.CF
- update to 1.1.1

* Sat Jun 21 2008 Paul Howarth <paul@city-fan.org> 1:1.1.0-1.0.CF
- update to upstream version 1.1.0 (with new source URL)
- update sieve plugin to 1.1.5
- remove unnecessary patches
- enable ldap and gssapi (where possible) plugins
- change ownership of dovecot.conf (resolves #452088)

* Wed Jun 18 2008 Paul Howarth <paul@city-fan.org> 1:1.0.14-9.0.CF
- update init script (resolves #451838); big release bump keeps up with
  Fedora 8 and 9 updates to maintain upgrade path

* Thu Jun  5 2008 Paul Howarth <paul@city-fan.org> 1:1.0.14-2.0.CF
- install convert-tool (resolves #450010)

* Tue Jun  3 2008 Paul Howarth <paul@city-fan.org> 1:1.0.14-1.0.CF
- update to 1.0.14
- update autotools patch

* Wed May 21 2008 Paul Howarth <paul@city-fan.org> 1:1.0.13-8.0.CF
- LSB-ize initscript (#238018)
- install dovecot.conf not world-readable (#445200)
- merge misc spec file cleanups from Rawhide
- rationalize scriptlets (#225708)

* Mon May 19 2008 Paul Howarth <paul@city-fan.org> 1:1.0.13-6.1.CF
- update sieve to 1.0.3

* Mon Mar 10 2008 Paul Howarth <paul@city-fan.org> 1:1.0.13-6.0.CF
- update to 1.0.13

* Wed Mar  5 2008 Paul Howarth <paul@city-fan.org> 1:1.0.12-1.0.CF
- update to 1.0.12

* Tue Mar  4 2008 Paul Howarth <paul@city-fan.org> 1:1.0.11-1.0.CF
- update to 1.0.11

* Tue Feb 26 2008 Paul Howarth <paul@city-fan.org> 1:1.0.10-5.0.CF
- rebuild for gcc 4.3.0 on Fedora 9

* Fri Jan 11 2008 Paul Howarth <paul@city-fan.org> 1:1.0.10-4.0.CF
- rebuild

* Wed Jan  2 2008 Paul Howarth <paul@city-fan.org> 1:1.0.10-1.0.CF
- Update to 1.0.10

* Wed Dec 12 2007 Paul Howarth <paul@city-fan.org> 1:1.0.9-1.0.CF
- Update to 1.0.9

* Fri Dec  7 2007 Paul Howarth <paul@city-fan.org> 1:1.0.8-1.1.CF
- Rebuild for new openldap and openssl in Rawhide

* Thu Nov 29 2007 Paul Howarth <paul@city-fan.org> 1:1.0.8-1.0.CF
- Update to 1.0.8

* Tue Nov  6 2007 Paul Howarth <paul@city-fan.org> 1:1.0.7-2.1.CF
- Add the winbind patch (#286351)
- Update autotools patch

* Wed Oct 31 2007 Paul Howarth <paul@city-fan.org> 1:1.0.7-1.1.CF
- Update to 1.0.7

* Mon Oct 29 2007 Paul Howarth <paul@city-fan.org> 1:1.0.6-1.1.CF
- Update to 1.0.6
- Update autotools patch
- Wiki snapshot now installed in correct directory upstream, so no need to
  move it in %%install

* Mon Oct  1 2007 Paul Howarth <paul@city-fan.org> 1:1.0.5-1.1.CF
- Fedora version has epoch bump, so mine must do too (grr...)

* Mon Sep 10 2007 Paul Howarth <paul@city-fan.org> 1.0.5-20.CF
- update to 1.0.5
- update download URL for dovecot
- update license tags
- make sure all documentation is UTF8

* Tue Aug  7 2007 Paul Howarth <paul@city-fan.org> 1.0.3-20.CF
- update to 1.0.3
- update autotools patch
- add quota-warning patch

* Fri Jul 20 2007 Paul Howarth <paul@city-fan.org> 1.0.2-22.CF
- update dovecot-sieve to 1.0.2

* Mon Jul 16 2007 Paul Howarth <paul@city-fan.org> 1.0.2-21.CF
- update to 1.0.2

* Mon Jun 18 2007 Paul Howarth <paul@city-fan.org> 1.0.1-20.CF
- update to 1.0.1
- specfile merge from Rawhide
  - new SQL split patch
  - split SQL libraries to separate packages

* Mon Apr 16 2007 Paul Howarth <paul@city-fan.org> 1.0.0-11.CF
- update to 1.0.0 (at last!)

* Fri Apr 13 2007 Paul Howarth <paul@city-fan.org> 1.0-0.10.CF.rc32
- update to 1.0.rc32

* Tue Apr 10 2007 Paul Howarth <paul@city-fan.org> 1.0-0.9.CF.rc31
- update to 1.0.rc31
- use --disable-dependency-tracking with configure script for faster builds
- add devel subpackage with headers for plugin writers

* Mon Apr  2 2007 Paul Howarth <paul@city-fan.org> 1.0-0.9.CF.rc29
- update to 1.0.rc29
- only rename the login dir on old distributions (FC4, RHEL4 and older) that
  don't clean up /var/run/dovecot properly
- build sieve plugin and package it in sieve subpackage
- preserve timestamps in installed data files where possible
- add --with-{doc,gssapi,inotify} configure options where appropriate
- package REDHAT-FAQ.txt
- move certificate generation script from %%{docdir} to %%{_libexecdir}

* Mon Mar 26 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc28
- update to 1.0.rc28
- put example configurations in %%{docdir} rather than %%{_sysconfdir}

* Thu Mar 15 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc27
- update to 1.0.rc27

* Wed Mar  7 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc26
- update to 1.0.rc26

* Fri Mar  2 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc25
- update to 1.0.rc25

* Fri Feb 23 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc24
- update to 1.0.rc24

* Wed Feb 21 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc23
- update to 1.0.rc23

* Wed Feb  7 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc22
- update to 1.0.rc22

* Mon Feb  5 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc21
- update to 1.0.rc21
- fix dist tag for fc7 onwards

* Wed Jan 24 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc19
- update to 1.0.rc19

* Mon Jan  8 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc17
- update to 1.0.rc17

* Wed Dec 13 2006 Paul Howarth <paul@city-fan.org> 1.0-0.7.CF.rc15
- update to 1.0.rc15

* Mon Oct 16 2006 Paul Howarth <paul@city-fan.org> 1.0-0.6.CF.rc9
- update to 1.0.rc9

* Tue Oct 10 2006 Paul Howarth <paul@city-fan.org> 1.0-0.5.CF.rc8
- update to 1.0.rc8
- update default-settings patch

* Tue Oct  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.4.CF.rc7
- rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Wed Sep 27 2006 Paul Howarth <paul@city-fan.org> 1.0-0.3.CF.rc7
- do not run over symlinked certificates in new locations on upgrade

* Thu Sep  7 2006 Paul Howarth <paul@city-fan.org> 1.0-0.2.CF.rc7
- fix distribution tags for development releases

* Fri Aug 18 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc7
- update to 1.0.rc7

* Tue Aug  8 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc6
- update to 1.0.rc6

* Thu Aug  5 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc5
- update to 1.0.rc5
- update default-settings patch

* Wed Jul  5 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc2
- update to 1.0.rc2
- update default-settings patch

* Wed Jun 28 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc1
- update to 1.0.rc1
- update default-settings patch
- shuffle bits of release tag around for saner upgrade path
- note that parts (dovecot-auth, lib-sql and lib-ntlm) are now MIT licensed
- DH parameters generated in new %%{_localstatedir}/lib/dovecot directory

* Wed Jun 14 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta9.CF.1
- update to 1.0.beta9
- update default-settings patch
- don't apply pam-setcred patch as it should no longer be needed

* Fri May 12 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta8.1
- update to 1.0.beta8
- drop lib64 patch, should no longer be needed

* Wed May  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta7.1
- update to 1.0.beta7
- update default settings and lib64 patches to apply against beta7

* Fri Mar  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta3.2
- fix #182240 by looking in lib64 for libs first and then lib
  (more complete fix than rawhide beta2 patch; also, this package was not
  affected by the missing sample configuration files issue)

* Fri Feb 10 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta3.1
- update to 1.0.beta3
- move %%{_localstatedir}/run/dovecot/login back to
  %%{_localstatedir}/run/dovecot-login to avoid spurious boot-time error
  messages about not being able to clear %%{_localstatedir}/run/dovecot
- use complete Fedora patch set and then apply our own patches
- change the compiled-in defaults and adjust the default's configfile
  commented-out example settings to match compiled-in defaults,
  instead of changing the defaults only in the configfile, as per #179432
- fix #179574 by providing a default uidl_format for pop3
- half-fix #179620 by having plaintext auth enabled by default... this
  needs more thinking (which one we really want) and documentation
  either way
- don't fiddle with autotools input files, work around install issues
  manually; this removes the dependencies on autotools and allows the package
  to build on much older distributions
- change %%post as main dovecot binary no longer generates DH SSL parameters

* Wed Feb  1 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta2.3
- move /var/run/dovecot-login to %%{_localstatedir}/run/dovecot/login
- call dovecot --build-ssl-parameters in postinst (#179430)

* Tue Jan 31 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta2.2
- sort out gettext buildreq to enable builds on older distributions
  (still work to do to get autotools working though)
- update distribution-detection code to enable builds on CentOS
- update URL

* Mon Jan 23 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta2.1
- update to 1.0.beta2

* Tue Jan 17 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta1.1
- update to 1.0.beta1

* Tue Jan 10 2006 Paul Howarth <paul@city-fan.org> 1.0-0.alpha5.1
- update to 1.0.alpha5
- update dovecot.conf patch to apply against 1.0.alpha5
- include plugins

* Wed Dec 14 2005 Paul Howarth <paul@city-fan.org> 1.0-0.alpha4.1
- general spec file rewrite
- don't require specific openssl version
- determine ssldir at build time for compatibility with more distro versions
- use --with options for mysql and postgresql rather than regular macros
- initscript is not %%config
- %%{docdir}/examples/mkcert.sh is used in %%post and cannot therefore be %%doc

* Thu Nov 24 2005 Willem Riede <wriede@riede.org>
- merge from fc5t1 dovecot 0.99.14 srpm

* Sat Oct 22 2005 Willem Riede <wriede@riede.org>
- use newly released alpha4

* Thu Aug 18 2005 Willem Riede <wriede@riede.org>
- use newly released alpha1

* Sun Jul 24 2005 Willem Riede <wriede@riede.org>
- Merge FC4 .spec with ATRPM and use latest stable

* Fri Apr 22 2005 John Dennis <jdennis@redhat.com> 0.99.14-4.fc4
- openssl moved its certs, CA, etc. from /usr/share/ssl to /etc/pki

* Tue Apr 12 2005 Tom Lane <tgl@redhat.com> 0.99.14-3.fc4
- Rebuild for Postgres 8.0.2 (new libpq major version).

* Mon Mar  7 2005 John Dennis <jdennis@redhat.com> 0.99.14-2.fc4
- bump rev for gcc4 build

* Mon Feb 14 2005 John Dennis <jdennis@redhat.com> 0.99.14-1.fc4
- fix bug #147874, update to 0.99.14 release

* Wed Feb  2 2005 John Dennis <jdennis@redhat.com> 0.99.13-4.devel
- fix bug #146198, clean up temp kerberos tickets

* Mon Jan 17 2005 John Dennis <jdennis@redhat.com> 0.99.13-3.devel
- fix bug #145214, force mbox_locks to fcntl only
- fix bug #145241, remove prereq on postgres and mysql, allow rpm auto
  dependency generator to pick up client lib dependency if needed.

* Thu Jan 13 2005 John Dennis <jdennis@redhat.com> 0.99.13-2.devel
- make postgres & mysql conditional build
- remove execute bit on migration example scripts so rpm does not pull
  in additional dependences on perl and perl modules that are not present
  in dovecot proper.
- add REDHAT-FAQ.txt to doc directory

* Thu Jan  6 2005 John Dennis <jdennis@redhat.com> 0.99.13-1.devel
- bring up to date with latest upstream, 0.99.13, bug #143707
  also fix bug #14462, bad dovecot-uid macro name

* Thu Jan  6 2005 John Dennis <jdennis@redhat.com> 0.99.11-10.devel
- fix bug #133618, removed LITERAL+ capability from capability string

* Wed Jan  5 2005 John Dennis <jdennis@redhat.com> 0.99.11-9.devel
- fix bug #134325, stop dovecot during installation

* Wed Jan  5 2005 John Dennis <jdennis@redhat.com> 0.99.11-8.devel
- fix bug #129539, dovecot starts too early,
  set chkconfig to 65 35 to match cyrus-imapd
- also delete some old commented out code from SSL certificate creation

* Thu Dec 23 2004 John Dennis <jdennis@redhat.com> 0.99.11-7.devel
- add UW to Dovecot migration documentation and scripts, bug #139954
  fix SSL documentation and scripts, add missing documentation, bug #139276

* Fri Dec 17 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to 1.0-test58.

* Tue Dec  7 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to 1.0-test56.

* Thu Nov 15 2004 Warren Togami <wtogami@redhat.com> 0.99.11-2.FC4.1
- rebuild against MySQL4

* Thu Oct 21 2004 John Dennis <jdennis@redhat.com>
- fix bug #136623
  Change License field from GPL to LGPL to reflect actual license

* Thu Sep 30 2004 John Dennis <jdennis@redhat.com> 0.99.11-1.FC3.3
- fix bug #124786, listen to ipv6 as well as ipv4

* Wed Sep  8 2004 John Dennis <jdennis@redhat.com> 0.99.11-1.FC3.1
- bring up to latest upstream,

* Wed Aug  4 2004 John Dennis <jdennis@redhat.com>
- change release field separator from comma to dot, bump build number

* Mon Aug  2 2004 John Dennis <jdennis@redhat.com> 0.99.10.9-1,FC3,1
- bring up to date with latest upstream, fixes include:
- LDAP support compiles now with Solaris LDAP library
- IMAP BODY and BODYSTRUCTURE replies were wrong for MIME parts which
  didn't contain Content-Type header.
- MySQL and PostgreSQL auth didn't reconnect if connection was lost
  to SQL server
- Linking fixes for dovecot-auth with some systems
- Last fix for disconnecting client when downloading mail longer than
  30 seconds actually made it never disconnect client. Now it works
  properly: disconnect when client hasn't read _any_ data for 30
  seconds.
- MySQL compiling got broken in last release
- More PostgreSQL reconnection fixing

* Mon Jul 26 2004 John Dennis <jdennis@redhat.com> 0.99.10.7-1,FC3,1
- enable postgres and mySQL in build
- fix configure to look for mysql in alternate locations
- nuke configure script in tar file, recreate from configure.in using autoconf

- bring up to latest upstream, which included:
- Added outlook-pop3-no-nuls workaround to fix Outlook hang in mails with NULs.
- Config file lines can now contain quoted strings ("value ")
- If client didn't finish downloading a single mail in 30 seconds,
  Dovecot closed the connection. This was supposed to work so that
  if client hasn't read data at all in 30 seconds, it's disconnected.
- Maildir: LIST now doesn't skip symlinks


* Wed Jun 30 2004 John Dennis <jdennis@redhat.com>
- bump rev for build
- change rev for FC3 build

* Fri Jun 25 2004 John Dennis <jdennis@redhat.com> 0.99.10.6-1
- bring up to date with upstream,
  recent change log comments from Timo Sirainen were:
  SHA1 password support using OpenSSL crypto library
  mail_extra_groups setting
  maildir_stat_dirs setting
  Added NAMESPACE capability and command
  Autocreate missing maildirs (instead of crashing)
  Fixed occational crash in maildir synchronization
  Fixed occational assertion crash in ioloop.c
  Fixed FreeBSD compiling issue
  Fixed issues with 64bit Solaris binary

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu May 27 2004 David Woodhouse <dwmw2@redhat.com> 0.99.10.5-1
- Update to 0.99.10.5 to fix maildir segfaults (#123022)

* Fri May 07 2004 Warren Togami <wtogami@redhat.com> 0.99.10.4-4
- default auth config that is actually usable
- Timo Sirainen (author) suggested functionality fixes
  maildir, imap-fetch-body-section, customflags-fix

* Mon Feb 23 2004 Tim Waugh <twaugh@redhat.com>
- Use ':' instead of '.' as separator for chown.

* Tue Feb 17 2004 Jeremy Katz <katzj@redhat.com> 0.99.10.4-3
- restart properly if it dies (#115594)

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Mon Nov 24 2003 Jeremy Katz <katzj@redhat.com> 0.99.10.4-1
- update to 0.99.10.4

* Mon Oct  6 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-7
- another patch from upstream to fix returning invalid data on partial 
  BODY[part] fetches
- patch to avoid confusion of draft/deleted in indexes

* Tue Sep 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-6
- add some patches from upstream (#104288)

* Thu Sep  4 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-5
- fix startup with 2.6 with patch from upstream (#103801)

* Tue Sep  2 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-4
- fix assert in search code (#103383)

* Tue Jul 22 2003 Nalin Dahyabhai <nalin@redhat.com> 0.99.10-3
- rebuild

* Thu Jul 17 2003 Bill Nottingham <notting@redhat.com> 0.99.10-2
- don't run by default

* Thu Jun 26 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-1
- 0.99.10

* Mon Jun 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-0.2
- 0.99.10-rc2 (includes ssl detection fix)
- a few tweaks from fedora
  - noreplace the config file
  - configure --with-ldap to get LDAP enabled

* Mon Jun 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-0.1
- 0.99.10-rc1
- add fix for ssl detection
- add zlib-devel to BuildRequires
- change pam service name to dovecot
- include pam config

* Thu May  8 2003 Jeremy Katz <katzj@redhat.com> 0.99.9.1-1
- update to 0.99.9.1
- add patch from upstream to fix potential bug when fetching with 
  CR+LF linefeeds
- tweak some things in the initscript and config file noticed by the 
  fedora folks

* Sun Mar 16 2003 Jeremy Katz <katzj@redhat.com> 0.99.8.1-2
- fix ssl dir
- own /var/run/dovecot/login with the correct perms
- fix chmod/chown in post

* Fri Mar 14 2003 Jeremy Katz <katzj@redhat.com> 0.99.8.1-1
- update to 0.99.8.1

* Tue Mar 11 2003 Jeremy Katz <katzj@redhat.com> 0.99.8-2
- add a patch to fix quoting problem from CVS

* Mon Mar 10 2003 Jeremy Katz <katzj@redhat.com> 0.99.8-1
- 0.99.8
- add some buildrequires
- fixup to build with openssl 0.9.7
- now includes a pop3 daemon (off by default)
- clean up description and %%preun
- add dovecot user (uid/gid of 97)
- add some buildrequires
- move the ssl cert to %%{_datadir}/ssl/certs
- create a dummy ssl cert in %%post
- own /var/run/dovecot
- make the config file a source so we get default mbox locks of fcntl

* Sun Dec  1 2002 Seth Vidal <skvidal@phy.duke.edu>
- 0.99.4 and fix startup so it starts imap-master not vsftpd :)

* Tue Nov 26 2002 Seth Vidal <skvidal@phy.duke.edu>
- first build
